# Lyra NSIS Install Script
#
# Author Martin Foster
# Version 1.0.1, %Revision%, %LastChangedDate%

# System Variables
!define PRODUCT_NAME "Lyra"
!define PRODUCT_VERSION "1.0.2"
!define PRODUCT_PUBLISHER "Ethereal Realms"
!define PRODUCT_WEB_SITE "http://www.ethereal-realms.org/lyra/"
!define PRODUCT_DIR_REGKEY "Software\Microsoft\Windows\CurrentVersion\App Paths\lyra.exe"
!define PRODUCT_UNINST_KEY "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_NAME}"
!define PRODUCT_UNINST_ROOT_KEY "HKLM"
!define PRODUCT_STARTMENU_REGVAL "NSIS:StartMenuDir"

# Compressor
SetCompressor bzip2

# Included files
!include MUI2.nsh

# MUI Settings
!define MUI_ABORTWARNING
!define MUI_ICON "..\icons\Lyra-Windows.ico"
!define MUI_UNICON "..\icons\Lyra-Windows.ico"

# Welcome page
!insertmacro MUI_PAGE_WELCOME

# License page
!insertmacro MUI_PAGE_LICENSE "..\LICENSE"

# Directory page
!insertmacro MUI_PAGE_DIRECTORY

# Start menu page
var ICONS_GROUP
!define MUI_FINISHPAGE_NOAUTOCLOSE
!define MUI_UNFINISHPAGE_NOAUTOCLOSE
!define MUI_STARTMENUPAGE_NODISABLE
!define MUI_STARTMENUPAGE_DEFAULTFOLDER "Lyra"
!define MUI_STARTMENUPAGE_REGISTRY_ROOT "${PRODUCT_UNINST_ROOT_KEY}"
!define MUI_STARTMENUPAGE_REGISTRY_KEY "${PRODUCT_UNINST_KEY}"
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "${PRODUCT_STARTMENU_REGVAL}"
!insertmacro MUI_PAGE_STARTMENU Application $ICONS_GROUP

# Instfiles page
!insertmacro MUI_PAGE_INSTFILES

# Finish page
!define MUI_FINISHPAGE_RUN "$INSTDIR\lyra.exe"
!define MUI_FINISHPAGE_SHOWREADME "$INSTDIR\docs\EN\Help.pdf"
!insertmacro MUI_PAGE_FINISH

# Uninstaller pages
!insertmacro MUI_UNPAGE_INSTFILES

# Language files
!insertmacro MUI_LANGUAGE "English"

# Installer Attributes
Name "${PRODUCT_NAME} ${PRODUCT_VERSION}"
OutFile "../../Lyra-Setup.exe"
InstallDir "$PROGRAMFILES\Lyra"
InstallDirRegKey HKLM "${PRODUCT_DIR_REGKEY}" ""
ShowInstDetails show
ShowUnInstDetails show

# Installer Section
Section "MainSection" SEC01

  # Main executable
  SetOutPath "$INSTDIR"
  SetOverwrite ifnewer
  File "..\lyra.exe"
  File "..\lyra.jar"
  
  # Configuration Directory
  SetOutPath "$INSTDIR\conf"
  File "..\conf\lyra.db3"

  # Host Template Entry
  SetOutPath "$INSTDIR\host"
  File "..\host\template.db3"

  # Directory handling
  SetOutPath "$INSTDIR"
  File /r ..\docs
  File /r ..\icons
  File /r ..\lang

  # Shortcut Directoru
  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
  CreateDirectory "$SMPROGRAMS\$ICONS_GROUP"
  CreateShortCut "$SMPROGRAMS\$ICONS_GROUP\Lyra.lnk" "$INSTDIR\lyra.exe"
  CreateShortCut "$DESKTOP\Lyra.lnk" "$INSTDIR\lyra.exe"
  !insertmacro MUI_STARTMENU_WRITE_END
SectionEnd

# Additional Icon Installation
Section -AdditionalIcons
  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
  CreateShortCut "$SMPROGRAMS\$ICONS_GROUP\Uninstall.lnk" "$INSTDIR\uninst.exe"
  !insertmacro MUI_STARTMENU_WRITE_END
SectionEnd

# Registry Operations
Section -Post
  WriteUninstaller "$INSTDIR\uninst.exe"
  WriteRegStr HKLM "${PRODUCT_DIR_REGKEY}" "" "$INSTDIR\lyra.exe"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "DisplayName" "$(^Name)"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "UninstallString" "$INSTDIR\uninst.exe"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "DisplayIcon" "$INSTDIR\lyra.exe"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "DisplayVersion" "${PRODUCT_VERSION}"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "URLInfoAbout" "${PRODUCT_WEB_SITE}"
  WriteRegStr ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}" "Publisher" "${PRODUCT_PUBLISHER}"
SectionEnd

# Prompt for Uninstallation
Function un.onInit
  MessageBox MB_ICONQUESTION|MB_YESNO|MB_DEFBUTTON2 "Are you sure you want to completely remove $(^Name) and all of its components?" IDYES +2
  Abort
FunctionEnd

# Prompt on Uninstallation Completion
Function un.onUninstSuccess
  HideWindow
  MessageBox MB_ICONINFORMATION|MB_OK "$(^Name) was successfully removed from your computer."
FunctionEnd

# Uninstallation Section
Section Uninstall
  !insertmacro MUI_STARTMENU_GETFOLDER "Application" $ICONS_GROUP
  
  # Remove the Icons at all Levels
  RmDir /r /REBOOTOK "$SMPROGRAMS\$ICONS_GROUP"
  RmDir /r /REBOOTOK "$INSTDIR"
  Delete /REBOOTOK "$DESKTOP\Lyra.lnk"

  # Registry Change
  DeleteRegKey ${PRODUCT_UNINST_ROOT_KEY} "${PRODUCT_UNINST_KEY}"
  DeleteRegKey HKLM "${PRODUCT_DIR_REGKEY}"
  SetAutoClose true
SectionEnd
