/**
 * Copyright (c) 2011, Martin Foster <martin@ethereal-realms.org>
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice, 
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright 
 *       notice, this list of conditions and the following disclaimer in the 
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Ethereal-Realms.org nor the names of its
 *       contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.lyra.Widgets;

import java.util.Map;


/**
 * Very basic cell renderer which translates position numbers for display 
 * to users.   Typically users start to count at 1 instead of 0, and as a
 * result we increment by 1 to make sure that the sequence starts 
 * appropriately.
 * <p>
 * @author Martin Foster
 * @version 1.0.2, %Revision, 99%, %LastChangedDate, 17/03/11 8:17PM%
 * @see CustomColorRenderer
 */
public class PositionCellRenderer extends CustomColorRenderer {

	// Serial Compliance
	private static final long serialVersionUID = 1L;
	
	/**
     * Simple pass through constructor for the class.
     * <p>
     * @param global Global Map containing colours and user settings.
     */
    public PositionCellRenderer(Map<String,String> global) {
    	
    	// Let the super class do all the work.
    	super(global); 
    }
    // End of constructor class

    
    /* (non-Javadoc)
     * @see javax.swing.table.DefaultTableCellRenderer#setValue(java.lang.Object)
     */
    public void setValue(Object value) {

    	/*
    	 * Simplistic action.  All that it does is increment the position
    	 * number by one.  People typically start their count by 1 and not
    	 * 0 as the Multimedia Player Daemon (MPD) does.
    	 */
    	if (value != null) {
    		
    		// Convert to an integer
			int position  = Integer.parseInt(value.toString());
			
			// Pass it onto the main structure
			super.setValue(++position);
    	}
    	
		/*
		 * There is no runtime available for this element.  Which 
		 * should normally never happen.   So we set it to a blank
		 * string and pass it along.
		 */
    	else {
    		super.setValue("");
    	}
    }
}
// End of PositionCellRenderer Class
